@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 module PostgreSQL.Binary.Encoder
 (
   run,
@@ -15,7 +16,10 @@ module PostgreSQL.Binary.Encoder
   bool,
   numeric,
   uuid,
-  json,
+  json_ast,
+  json_bytes,
+  jsonb_ast,
+  jsonb_bytes,
   char,
   text_strict,
   text_lazy,
@@ -218,11 +222,30 @@ uuid :: Encoder UUID
 uuid =
   premap UUID.toWords (tuple4 int4_word32 int4_word32 int4_word32 int4_word32)
 
-{-# INLINABLE json #-}
-json :: Encoder Aeson.Value
-json =
+{-# INLINABLE json_ast #-}
+json_ast :: Encoder Aeson.Value
+#if MIN_VERSION_aeson(0,10,0)
+json_ast =
   Aeson.fromEncoding . Aeson.toEncoding
+#else
+json_ast =
+  Builder.lazyByteString . Aeson.encode
+#endif
 
+{-# INLINABLE json_bytes #-}
+json_bytes :: Encoder ByteString
+json_bytes =
+  Builder.byteString
+
+{-# INLINABLE jsonb_ast #-}
+jsonb_ast :: Encoder Aeson.Value
+jsonb_ast =
+  \x -> "\1" <> json_ast x
+
+{-# INLINABLE jsonb_bytes #-}
+jsonb_bytes :: Encoder ByteString
+jsonb_bytes =
+  \x -> "\1" <> Builder.byteString x
 
 -- * Text
 -------------------------
